@@ -46,6 +46,9 @@ def colored(text, color="blue"):
         return termcolor.colored(text, color)
     return text
 
+# constants
+COMPANY_NAME = "Mobilize.Net"
+
 # global status values
 max_errors = 1
 current_error_count = 0
@@ -221,6 +224,7 @@ def log_on(user=None, password=None, account=None, database=None, warehouse=None
             account=account,
             database=database,
             warehouse=warehouse,
+            application=COMPANY_NAME,
             role=role,
             login_timeout=login_timeout,
             session_parameters={
@@ -712,13 +716,16 @@ class Export:
     def report(file, separator=' '):
         Export.separator = separator
         Export.expandedfilename = path.expandvars(file)
-    @deprecated(version='1.9', reason="This function will be removed soon")
+    @staticmethod
+    @deprecated(reason="This function will be removed soon", version='1.9')
     def title_dashes(state="ON", withValue=None):
         pass
-    @deprecated(version='1.9', reason="This function will be removed soon")
+    @staticmethod
+    @deprecated(reason="This function will be removed soon", version='1.9')
     def width(width):
         pass
-    @deprecated(version='1.9', reason="This function will be removed soon")
+    @staticmethod
+    @deprecated(reason="This function will be removed soon", version='1.9')
     def reset():
         Export.expandedfilename = None
         Export.separator = ' '
